<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

class InvoiceRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [
            'customer_name' => ['required', 'string'],
            'customer_email' => ['required', 'email'],
            'term' => ['required', 'numeric','exists:terms,id'],
            'start_date' => ['required', 'date'],
            'end_date' => ['required', 'date'],
            'address' => ['required', 'string'],
            'latitude' => ['required_with:longitude', 'regex:/^[-]?((((1[0-7][0-9])|([0-9]?[0-9]))\.(\d+))|180(\.0+)?)$/'],
            'longitude' => ['required_with:latitude', 'regex:/^[-]?(([0-8]?[0-9])\.(\d+))|(90(\.0+)?)$/'],
            'message' => ['required', 'string'],
            'image' => ['image','mimes:jpg,png,jpeg,gif,svg','max:2048'],
            'sub_total' => ['required', 'numeric'],
            'total' => ['required', 'numeric'],
            'discount' => ['required', 'numeric'],
            'discount_type' => ['required', 'in:percent,price'],
            'sale_tax' => ['required', 'numeric'],
            'deposit' => ['required', 'numeric'],
            'list' => ['required', 'array'],
            'list.*.service' => ['required', 'string'],
            'list.*.description' => ['required', 'string'],
            'list.*.quantity' => ['required', 'numeric'],
            'list.*.rate' => ['required', 'numeric'],
            'list.*.amount' => ['required', 'numeric'],
            'subject' => ['required', 'string'],
            'body' => ['required', 'string']
        ];
    }
}
