<?php

namespace App\Models;

use App\Events\ChatEvent;
use App\Models\Admin\Structure\BillingPlan;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Illuminate\Support\Facades\Storage;
use Laravel\Sanctum\HasApiTokens;
use Mojtaba\Chatable\Models\Message as Messages;
use Mojtaba\Chatable\Traits\Chatable;

class User extends Authenticatable
{
    use HasApiTokens, HasFactory, Notifiable, Chatable,SoftDeletes;

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */

    protected $guarded = [
        'id'
    ];


    protected $hidden = [
        'password',
        'remember_token',
    ];
    protected $appends=['Type','role_client'];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
        'start_date' => 'datetime',
    ];
    public function sendChatMessageEvent(Messages $message)
    {
//        if ($message->type == 'chat')
        event(new ChatEvent($message));
//        else
//            event(new GroupEvent($message));

    }

    public function job_title()
    {
        return $this->belongsTo(JobTitle::class);
    }

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */


    public function socialMedias()
    {
        return $this->morphToMany(SocialMedia::class, 'social_mediable');
    }
//    public function social()
//    {
//        return $this->morphMany(SocialMedia::class, 'social_mediable');
//    }

    public function jobTitle()
    {
        return $this->belongsTo(JobTitle::class, 'job_title_id');
    }

    public function reports()
    {
        return $this->morphMany(Report::class, 'reportable');
    }

    public function getImageAttribute($value)
    {
        //dd(Storage::url('/images'));
        return $value != null ? Storage::disk('public')->url('images/' . $value) : $value;
    }

    public function participantsProject()
    {
        return $this->morphToMany(Project::class, 'participants_project','participants_project');
    }

    public function commenting()
    {
        return $this->belongsToMany(User::class, 'followers', 'follower_id', 'following_id');
    }

// users that follow this user
    public function followers()
    {
        return $this->belongsToMany(User::class, 'followers', 'following_id', 'follower_id');
    }

//    public function comments(){
//        return $this->;
//
//    }

    public function parentComments()
    {
        return $this->comments()->where('parent_id', 0);
    }

    public function subscribers()
    {
        return $this->morphToMany(BillingPlan::class, 'client');
    }

    public function transactions()
    {
        return $this->morphMany(Transaction::class, 'client');
    }

    public function invitations()
    {
        return $this->morphMany(Invite::class, 'client');
    }

    public function inviter()
    {
        return $this->morphMany(Invite::class, 'inviter');
    }

    public function countProject()
    {
        return $this->morphOne(CountProject::class, 'client');
    }

    public function images()
    {
        return $this->morphMany(Image::class, 'client');
    }

    public function estimates()
    {
        return $this->morphMany(Estimate::class, 'estimateable');
    }

    public function invoices()
    {
        return $this->morphMany(Invoice::class, 'invoiceable');
    }

    public function customers()
    {
        return $this->morphMany(Customer::class, 'customerable');
    }

    public function clientList()
    {
        return $this->morphMany(ServiceList::class, 'clientList');
    }

    public function clientComments()
    {
        return $this->morphMany(Comment::class, 'client');
    }

    public function profileComments()
    {
        return $this->morphMany(Comment::class, 'profile');
    }

    public function clientJobs()
    {
        return $this->morphMany(Job::class, 'client');
    }
    public function rates()
    {
        return $this->morphone(Rate::class, 'rateable','rateable_type','rateable_id');
    }
    public function projects()
    {
        return $this->morphMany(Project::class, 'projectable');
    }


    public function address()
    {
        return $this->morphOne(Address::class, 'addressable', "addressable_type", "addressable_id");
    }
    public function industry(){
        return $this->hasOne(JobTitle::class,'job_title_id','id');
    }
    public function getTypeAttribute(){
        return 'user';
    }

    public function specialCommentsClient()
    {
        return $this->morphOne(SpecialComment::class, 'client');
    }
    public function specialCommentsProfile()
    {
        return $this->morphOne(SpecialComment::class, 'profile');
    }
    public function getRoleClientAttribute(){
        return 'user';
    }
//$table->integer('total_invitation');
//$table->integer('received_project');
//$table->integer('used_project');
//$table->integer('remaining_project'); //project that don't used
//$table->integer('remaining_invited_client'); //the invited client that didn't get project from
}
